Skip to main content

HorribleSubs Downloader

A simple anime torrent downloader.

Features:

  • Quickly download anime torrents from HorribleSubs in your terminal.
  • Download the whole season in a single command.
  • Use alias for anime with long name.

Note: The downloader doesn't work for older anime that has no torrent link. Support for magnet link will be added in the future.


Table of Contents


Installation

You need Python 3.x.x to install and use the downloader. You also need Google Chrome (Support for Firefox and other browsers will be added in the future).

pip install horriblesubs-downloader
  1. Download chromedriver and extract out the file inside the ZIP.
  2. Type in your terminal: hsd --config driver_path <PATH TO CHROMEDRIVER>
  3. Set your download path: hsd --config download_path <PATH>
  4. You're ready to download some anime!

Usage

Usage:
    hsd <name> <episode> [--res <res>] [--to <path>]
    hsd <name> <start> <end> [--res <res>] [--to <path>]
    hsd <name> --batch [--res <res>] [--to <path>]
    hsd --alias [<alias>] [<real>]
    hsd --config [<key>] [<value>]

Options:
    -h --help           Show this screen.
    -b --batch          Download multiple torrents.
    -r --res <res>      Set resolution.
    -t --to <path>      Download file to path.
    -a --alias          Display or set alias.
    -c --config         Display or set config.

Examples

# Download episode 5 of One Punch Man
hsd "One Punch Man" 5

# Download episode 1-3 of KonoSuba
hsd --alias "KonoSuba" "Kono Subarashii Sekai ni Shukufuku wo!"
hsd "KonoSuba" 1 3

# Download the whole season of Steins Gate in 720p
hsd "Steins Gate" --batch --res 720

# Display all aliases and config
hsd --alias
hsd --config

License

MIT License

Download files

Download the file for your platform. If you're not sure which to choose, learn more about installing packages.

Source Distribution

horriblesubs_downloader-1.0.tar.gz (5.4 kB view details)

Uploaded Source

Built Distribution

If you're not sure about the file name format, learn more about wheel file names.

horriblesubs_downloader-1.0-py3-none-any.whl (6.9 kB view details)

Uploaded Python 3

File details

Details for the file horriblesubs_downloader-1.0.tar.gz.

File metadata

  • Download URL: horriblesubs_downloader-1.0.tar.gz
  • Upload date:
  • Size: 5.4 kB
  • Tags: Source
  • Uploaded using Trusted Publishing? No
  • Uploaded via: twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.6.2

File hashes

Hashes for horriblesubs_downloader-1.0.tar.gz
Algorithm Hash digest
SHA256 e5af10a9787b3b5344a8d9b0cdc47dd2138af2b0e91c039ce08908cfc64f6508
MD5 9b95df1cb86d2ea60f3ff319777a9454
BLAKE2b-256 1462229909f3d671076cbe391f213ff5599f5d3983a2b2731a451d1434d715be

See more details on using hashes here.

File details

Details for the file horriblesubs_downloader-1.0-py3-none-any.whl.

File metadata

  • Download URL: horriblesubs_downloader-1.0-py3-none-any.whl
  • Upload date:
  • Size: 6.9 kB
  • Tags: Python 3
  • Uploaded using Trusted Publishing? No
  • Uploaded via: twine/1.12.1 pkginfo/1.4.2 requests/2.19.1 setuptools/40.4.3 requests-toolbelt/0.8.0 tqdm/4.26.0 CPython/3.6.2

File hashes

Hashes for horriblesubs_downloader-1.0-py3-none-any.whl
Algorithm Hash digest
SHA256 e84520b0bb9e7887dae16fefe6a0d92c8ab4ff79bb59e5641783d1c683b48a8c
MD5 cc10fdc022c6a87e674aeca539cf2d7c
BLAKE2b-256 ee703216b32403564fc612fc043b2b7164b3f1905abd8c9820ad8457d586636d

See more details on using hashes here.

Release history Release notifications | RSS feed

1.0.1

2 files

This release

1.0 This release

2 files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page